function func_plotFullFieldImageSeq(savePath,plotParams,labelStrs,pos,time,plotVars)
% Author: Lloyd Fletcher
% PhotoDyn Group, University of Southampton
% Date: 13/3/2017
%
% Plots 2D frames of data as an image sequence
    
    % Create a struct of formatting properties for the figure
    plotProps = func_initPlotPropsStruct(plotParams.formatType);
    
    % Specify the range of data points to plot on the image  
    if  plotParams.cutEdgePx
        rangeX = (plotParams.cutPxX+1):size(plotVars{1},2)-plotParams.cutPxX;
        rangeY = (plotParams.cutPxY+1):size(plotVars{1},1)-plotParams.cutPxY;
    else
        rangeX = 1:size(plotVars{1},2);
        rangeY = 1:size(plotVars{1},1);
    end
    
    % Check that the number of subplots and number of vars in the plot vars 
    % cell is consistent
    numPlots = length(plotVars);
    checkNumPlots = plotParams.Rows*plotParams.Cols;
    if numPlots ~= checkNumPlots
        disp('WARNING: number of plot vars is not equal to specified number of subplots.')
    end
    
    % Calculate the colorbar range for each variable to be plotted
    if isfield(plotParams,'cAxisType')
        if ~strcmp(plotParams.cAxisType,'Specified')                
            for p = 1:numPlots 
                plotParams.cRange{p} = func_calcColourBarRange(plotParams.cAxisType,...
                    plotVars{p}(rangeY,rangeX,:));
            end
        end
    end
        
    % Create and size the figure
    hf = figure('Visible','On');
        set(hf,'Position', [plotProps.locX,plotProps.locY,...
        1.5*plotParams.Cols*plotProps.sizePerFigX,1.5*plotParams.Rows*plotProps.sizePerFigY])
    set(hf,'PaperPositionMode','auto')
    % Loop over each frame and plot it
    for f = 1:time.numFrames
        for p = 1:numPlots
            hold on
            % Create the subplot
            subplot(plotParams.Rows,plotParams.Cols,p)
            % Plot the image variable frame by fram
            imagesc(pos.x(rangeX)*10^3,pos.y(rangeY)*10^3,plotVars{p}(rangeY,rangeX,f))
            if isfield(plotParams,'titleFrameNum')
                if plotParams.titleFrameNum
                    titleStr = {labelStrs.t{p},[sprintf('Time: %.1f',time.vec(f)*10^6),'\mus, ',sprintf('Frame: %i',f)]};
                else
                    titleStr =[labelStrs.t{p},sprintf(', Time: %.1f',time.vec(f)*10^6),'\mus'];
                end
            else
                titleStr = [labelStrs.t{p},sprintf(', Time: %.1f',time.vec(f)*10^6),'\mus'];
            end
            title(titleStr,'fontsize',plotProps.hfs,'fontname',plotProps.ft) 
            set(gca, 'fontsize', plotProps.fs,'fontname',plotProps.ft)
            axis image
            % Create a colour bar and set the colour map
            colorbar
            colormap(jet)
            % Determine the colour bar range 
            if isfield(plotParams,'cAxisType')
                if ~strcmp(plotParams.cAxisType,'Auto')
                    if isfield(plotParams,'cRange')
                        caxis(plotParams.cRange{p})
                    end
                end
            end
            % Remove the image axes if required
            if ~plotParams.imageAxis
                axis off
            else
                xlabel(labelStrs.x,'fontsize',plotProps.hfs,'fontname',plotProps.ft);
                ylabel(labelStrs.y,'fontsize',plotProps.hfs,'fontname',plotProps.ft);
            end
            hold off  
        end
        
        % Save this frame to file
        print(hf,[savePath,'\Frame_',num2str(f)],plotProps.format,'-r0')
        clf(hf);
    end

end

